@@ -1,5 +1,3 @@
-context("switch statements")
-
 # switch for effect size type works ------------------------------------------
 
 testthat::test_that(
@@ -23,21 +21,3 @@ testthat::test_that(
     testthat::expect_identical(effsize_type_switch("xyz"), "unbiased")
   }
 )
-
-
-# switch for stats type works ------------------------------------------
-
-testthat::test_that(
-  desc = "switch for stats type works",
-  code = {
-    testthat::skip_if(getRversion() < "3.6")
-
-    testthat::expect_identical(stats_type_switch("p"), "parametric")
-    testthat::expect_identical(stats_type_switch("pearson"), "parametric")
-    testthat::expect_identical(stats_type_switch("non-parametric"), "nonparametric")
-    testthat::expect_identical(stats_type_switch("np"), "nonparametric")
-    testthat::expect_identical(stats_type_switch("r"), "robust")
-    testthat::expect_identical(stats_type_switch("bf"), "bayes")
-    testthat::expect_identical(stats_type_switch("xxx"), "parametric")
-  }
-)
